
TODO: Improve this readme.

# PyBullet Robotics Examples

Demonstrations of deep reinforcement learning algorithms for robotics environments implemented with cherry.

## Requirements

* Gym, torch, and cherry installed.
* PyBullet, see instructions below.

### PyBullet

#### Install instructions

## Examples Descriptions

### SAC

**Status** Replicates RLkit's SAC. 

### Delayed Twin-SAC

**Status** Replicates RLkit's twin-SAC, and adds an optional delay parameters for improved stability.

### PPO

**Status** Replicates Ilya Kostrikov's PPO. 
